@@ -8,6 +8,7 @@
 */
 
 #include "ai.h"
+#include <QRandomGenerator>
 
 AI::AI(Sea::Player player, Sea* sea, const BattleShipsConfiguration* config)
 : m_player(player)
@@ -35,13 +36,14 @@ void AI::setShips()
     // TODO: Another placing algorithm, create a list of available places and choose randomly from them.
     // number of repetitions because the random place is over a previous ship = 0
     bool canFinish = true;
+    auto *generator = QRandomGenerator::global();
     do {
         for (int size = m_config->longestShip(); size >= 1; size--) {
             for (unsigned int j = 1; j <= m_config->numberOfShipsOfSize(size); j++) {
                 Ship* ship = 0;
                 while (ship == 0 && canFinish) {
-                    Coord c(qrand() % m_sea->size().x, qrand() % m_sea->size().y);
-                    Ship::Direction dir = qrand() % 2 == 0 ? Ship::LEFT_TO_RIGHT : Ship::TOP_DOWN;
+                    Coord c(generator->bounded(m_sea->size().x), generator->bounded(m_sea->size().y));
+                    Ship::Direction dir = generator->bounded(2) == 0 ? Ship::LEFT_TO_RIGHT : Ship::TOP_DOWN;
                     if (m_sea->canAddShip(m_player, c, size, dir)) {
                         ship = new Ship(size, dir, c);
                         m_sea->add(m_player, ship);
